Learn R Programming

orthopolynom (version 1.0-2)

chebyshev.c.recurrences: Recurrence relations for Chebyshev polynomials

Description

This function returns a data frame with $n$+1 rows and four named columns containing the coefficient vectors c, d, e and f of the recurrence relations for the order $k$ Chebyshev polynomial of the first kind, $C_k \left( x \right)$, and for orders $k$ = 0, 1, ... , $n$.

Usage

chebyshev.c.recurrences(n, normalized=FALSE)

Arguments

n
integer highest polynomial order
normalized
boolean value which, if TRUE, returns recurrence relations for normalized polynomials

Value

  • A data frame with the recurrence relation parameters.

References

Abramowitz and Stegun (1968)

See Also

chebyshev.c.inner.products,

Examples

Run this code
normalized.r <- chebyshev.c.recurrences( 10, normalized=TRUE )
unnormalized.r <- chebyshev.c.recurrences( 10, normalized=FALSE )

Run the code above in your browser using DataLab