Learn R Programming

orthopolynom (version 1.0-3)

ghermite.h.inner.products: Inner products of generalized Hermite polynomials

Description

This function returns a vector with $n + 1$ elements containing the inner product of an order $k$ generalized Hermite polynomial, $H_k^{\left( \mu \right)} \left( x \right)$, with itself (i.e. the norm squared) for orders $k = 0,\;1,\; \ldots ,\;n$.

Usage

ghermite.h.inner.products(n, mu)

Arguments

n
n integer value for the highest polynomial order
mu
mu polynomial parameter

Value

  • A vector with $n + 1$ elements
  • 1inner product of order 0 orthogonal polynomial
  • 2inner product of order 1 orthogonal polynomial
  • ...
  • n+1inner product of order $n$ orthogonal polynomial

Details

The parameter $\mu$ must be greater than -0.5. The formula used to compute the inner products is as follows. $h_n \left( \mu \right) = \left\langle {H_m^{\left( \mu \right)} |H_n^{\left( \mu \right)} } \right\rangle = 2^{2\,n} \,\left[ {\frac{n} {2}} \right]!\;\Gamma \left( {\left[ {\frac{{n + 1}} {2}} \right] + \mu + \frac{1} {2}} \right)$

References

Abramowitz, M. and I. A. Stegun, 1968. Handbook of Mathematical Functions with Formulas, Graphs, and Mathematical Tables, Dover Publications, Inc., New York. Courant, R., and D. Hilbert, 1989. Methods of Mathematical Physics, John Wiley, New York, NY. Szego, G., 1939. Orthogonal Polynomials, 23, American Mathematical Society Colloquium Publications, Providence, RI.

Examples

Run this code
###
### generate the inner products vector for the
### generalized Hermite polynomials of orders 0 to 10
### polynomial parameter is 1
###
h <- ghermite.h.inner.products( 10, 1 )
print( h )

Run the code above in your browser using DataLab