Learn R Programming

orthopolynom (version 1.0-2)

ghermite.h.recurrences: Recurrence relations for generalized Hermite polynomials

Description

This function returns a data frame with $n$+1 rows and four named columns containing the coefficient vectors c, d, e and f of the recurrence relations for the order $k$ generalized Hermite polynomial, $H_k^{\left( \mu \right)} \left( x \right)$, and for orders $k$ = 0, 1, ... , $n$.

Usage

ghermite.h.recurrences(n, mu, normalized = FALSE)

Arguments

n
n integer highest polynomial order
mu
mu polynomial parameter
normalized
normalized boolean value which, if TRUE, returns recurrence relations for normalized polynomials

Value

  • A data frame with the recurrence relation parameters.

Details

The parameter $\mu$ must be greater than -0.5.

References

Alvarez-Nordase, Atakishiyeva, Atakishiyeva (2004)

See Also

ghermite.h.inner.products,

Examples

Run this code
normalized.r <- ghermite.h.recurrences( 10, 1, normalized=TRUE )
unnormalized.r <- ghermite.h.recurrences( 10, 1, normalized=FALSE )

Run the code above in your browser using DataLab