ghermite.h.weight: Weight function for the generalized Hermite polynomial
Description
This function returns the value of the weight function for the order $k$
generalized Hermite polynomial, $H_k^{\left( \mu \right)} \left( x \right)$.
Usage
ghermite.h.weight(x, mu)
Arguments
x
a numeric vector function argument
mu
polynomial parameter
Value
The value of the weight function
Details
The function takes on non-zero values in the interval $\left( -\infty,\infty \right)$.
The parameter $\mu$ must be greater than -0.5. The formula used to compute the
generalized Hermite weight function is as follows.
$w\left( {x,\mu } \right) = \left| x \right|^{2\;\mu } \;\exp \left( { - x^2 } \right)$
References
Abramowitz, M. and I. A. Stegun, 1968. Handbook of Mathematical Functions with
Formulas, Graphs, and Mathematical Tables, Dover Publications, Inc., New York.
Courant, R., and D. Hilbert, 1989. Methods of Mathematical Physics,
John Wiley, New York, NY.
Press, W. H., S. A. Teukolsky, W. T. Vetterling, and B. P. Flannery, 1992.
Numerical Recipes in C, Cambridge University Press, Cambridge, U.K.
Szego, G., 1939. Orthogonal Polynomials, 23, American Mathematical Society
Colloquium Publications, Providence, RI.
###### compute the generalized Hermite weight function for argument values ### between -3 and 3###x <- seq( -3, 3, .01 )
y <- ghermite.h.weight( x, 1 )