Learn R Programming

orthopolynom (version 1.0-2)

glaguerre.polynomials: Create list of generalized Laguerre polynomials

Description

This function returns a list with $n$+1 elements containing the order $k$ generalized Laguerre polynomials, $L_n^{\left( \alpha \right)} \left( x \right)$, for orders $k$ = 0, 1, ..., $n$.

Usage

glaguerre.polynomials(n, alpha, normalized=FALSE)

Arguments

n
integer highest polynomial order
alpha
polynomial parameter
normalized
a boolean value which, if TRUE, returns a list of normalized orthogonal polynomials

Value

  • A list of $n$+1 polynomial objects
  • 1order 0 generalized Laguerre polynomial
  • 2order 1 generalized Laguerre polynomial
  • ...
  • n+1order $n$ generalized Laguerre polynomial

Details

The function produces a data frame with the recurrence relation parameters for the orthogonal polynomials. It then uses the function orthogonal.polynomials to construct the list of polynomial objects from the recurrence relations.

References

Abramowitz and Stegun (1968)

See Also

glaguerre.recurrences, orthogonal.polynomials, orthonormal.polynomials

Examples

Run this code
normalized.p.list <- glaguerre.polynomials( 10, 1, normalized=TRUE )
unnormalized.p.list <- glaguerre.polynomials( 10, 1, normalized=FALSE )

Run the code above in your browser using DataLab