Learn R Programming

orthopolynom (version 1.0-2)

glaguerre.recurrences: Recurrence relations for generalized Laguerre polynomials

Description

This function returns a data frame with $n$+1 rows and four named columns containing the coefficient vectors c, d, e and f of the recurrence relations for the order $k$ generalized Laguerre polynomial, $L_n^{\left( \alpha \right)} \left( x \right)$, and for orders $k$ = 0, 1, ... , $n$.

Usage

glaguerre.recurrences(n, alpha, normalized=FALSE)

Arguments

n
integer highest polynomial order
alpha
polynomial parameter
normalized
boolean value which, if TRUE, returns recurrence relations for normalized polynomials

Value

  • A data frame with the recurrence relation parameters.

References

Abramowitz and Stegun (1968)

See Also

glaguerre.inner.products,

Examples

Run this code
normalized.r <- glaguerre.recurrences( 10, 1, normalized=TRUE )
unnormalized.r <- glaguerre.recurrences( 10, 1, normalized=FALSE )

Run the code above in your browser using DataLab