Learn R Programming

orthopolynom (version 1.0-2)

hermite.h.polynomials: Create list of Hermite polynomials

Description

This function returns a list with $n$+1 elements containing the order $k$ Hermite polynomials, $H_k \left( x \right)$, for orders $k$ = 0, 1, ..., $n$.

Usage

hermite.h.polynomials(n, normalized=FALSE)

Arguments

n
integer highest polynomial order
normalized
a boolean value which, if TRUE, returns a list of normalized orthogonal polynomials

Value

  • A list of $n$+1 polynomial objects
  • 1order 0 Hermite polynomial
  • 2order 1 Hermite polynomial
  • ...
  • n+1order $n$ Hermite polynomial

Details

The function produces a data frame with the recurrence relation parameters for the orthogonal polynomials. It then uses the function orthogonal.polynomials to construct the list of polynomial objects from the recurrence relations.

References

Abramowitz and Stegun (1968)

See Also

hermite.h.recurrences, orthogonal.polynomials, orthonormal.polynomials

Examples

Run this code
normalized.p.list <- hermite.h.polynomials( 10, normalized=TRUE )
unnormalized.p.list <- hermite.h.polynomials( 10, normalized=FALSE )

Run the code above in your browser using DataLab