jacobi.g.polynomials: Create list of Jacobi polynomials
Description
This function returns a list with $n$+1 elements containing the order $k$ Jacobi polynomials, $G_k \left( {p,q,x} \right)$, for orders $k$ = 0, 1, ..., $n$.
Usage
jacobi.g.polynomials(n, p, q, normalized=FALSE)
Arguments
n
integer highest polynomial order
p
first polynomial parameter
q
second polynomial parameter
normalized
a boolean value which, if TRUE, returns a list of normalized orthogonal polynomials
Value
A list of $n$+1 polynomial objects
1order 0 Jacobi polynomial
2order 1 Jacobi polynomial
...
n+1order $n$ Chebyshev polynomial
Details
The function produces a data frame with the recurrence relation parameters for the orthogonal polynomials. It then uses the function orthogonal.polynomials to construct the list of polynomial objects from the recurrence relations.