Learn R Programming

orthopolynom (version 1.0-2)

jacobi.g.recurrences: Recurrence relations for Jacobi polynomials

Description

This function returns a data frame with $n$+1 rows and four named columns containing the coefficient vectors c, d, e and f of the recurrence relations for the order $k$ Jacobi polynomial, $G_k \left( {p,q,x} \right)$, and for orders $k$ = 0, 1, ... , $n$.

Usage

jacobi.g.recurrences(n, p, q, normalized=FALSE)

Arguments

n
integer highest polynomial order
p
first polynomial parameter
q
second polynomial parameter
normalized
boolean value which, if TRUE, returns recurrence relations for normalized polynomials

Value

  • A data frame with the recurrence relation parameters.

References

Abramowitz and Stegun (1968)

See Also

jacobi.g.inner.products, pochhammer

Examples

Run this code
normalized.r <- jacobi.g.recurrences( 10, 3, 2, normalized=TRUE )
unnormalized.r <- jacobi.g.recurrences( 10, 3, 2, normalized=FALSE )

Run the code above in your browser using DataLab