Learn R Programming

orthopolynom (version 1.0-2)

jacobi.p.inner.products: Inner products of Jacobi polynomials

Description

This function returns a vector with $n$+1 elements containing the inner product of an order $k$ Jacobi polynomial, $P_k^{\left( {\alpha ,\beta } \right)} \left( x \right)$, with itself (i.e. the norm squared) for orders $k$ = 0, 1, ... , $n$.

Usage

jacobi.p.inner.products(n,a,b)

Arguments

n
integer highest polynomial order
a
first polynomial parameter
b
first polynomial parameter

Value

  • A vector with $n$+1 elements
  • 1inner product of order 0 orthogonal polynomial
  • 2inner product of order 1 orthogonal polynomial
  • ...
  • n+1inner product of order $n$+1 orthogonal polynomial

Details

~~ If necessary, more details than the description above ~~

References

Abramowitz and Stegun (1968)

Examples

Run this code
h <- jacobi.p.inner.products( 10, 2, 2 )

Run the code above in your browser using DataLab