Learn R Programming

orthopolynom (version 1.0-2)

jacobi.p.polynomials: Create list of Jacobi polynomials

Description

This function returns a list with $n$+1 elements containing the order $k$ Jacobi polynomials, $P_k^{\left( {\alpha ,\beta } \right)} \left( x \right)$, for orders $k$ = 0, 1, ..., $n$.

Usage

jacobi.p.polynomials(n, a, b, normalized=FALSE)

Arguments

n
integer highest polynomial order
a
first polynomial parameter
b
second polynomial parameter
normalized
a boolean value which, if TRUE, returns a list of normalized orthogonal polynomials

Value

  • A list of $n$+1 polynomial objects
  • 1order 0 Jacobi polynomial
  • 2order 1 Jacobi polynomial
  • ...
  • n+1order $n$ Chebyshev polynomial

Details

The function produces a data frame with the recurrence relation parameters for the orthogonal polynomials. It then uses the function orthogonal.polynomials to construct the list of polynomial objects from the recurrence relations.

References

Abramowitz and Stegun (1968)

See Also

jacobi.p.recurrences, orthogonal.polynomials, orthonormal.polynomials

Examples

Run this code
normalized.p.list <- jacobi.p.polynomials( 10, 2, 2, normalized=TRUE )
unnormalized.p.list <- jacobi.p.polynomials( 10, 2, 2, normalized=FALSE )

Run the code above in your browser using DataLab