Learn R Programming

orthopolynom (version 1.0-2)

jacobi.p.recurrences: Recurrence relations for Jacobi polynomials

Description

This function returns a data frame with $n$+1 rows and four named columns containing the coefficient vectors c, d, e and f of the recurrence relations for the order $k$ Jacobi polynomial, $P_k^{\left( {\alpha ,\beta } \right)} \left( x \right)$, and for orders $k$ = 0, 1, ... , $n$.

Usage

jacobi.p.recurrences(n, a, b, normalized=FALSE)

Arguments

n
integer highest polynomial order
a
first polynomial parameter
b
second polynomial parameter
normalized
boolean value which, if TRUE, returns recurrence relations for normalized polynomials

Value

  • A data frame with the recurrence relation parameters.

References

Abramowitz and Stegun (1968)

See Also

jacobi.p.inner.products, pochhammer

Examples

Run this code
normalized.r <- jacobi.p.recurrences( 10, 2, 2, normalized=TRUE )
unnormalized.r <- jacobi.p.recurrences( 10, 2, 2, normalized=FALSE )

Run the code above in your browser using DataLab