jacobi.p.weight: Weight function for the Jacobi polynomial
Description
This function returns the value of the weight function for the order $k$
Jacobi polynomial, $P_k^{\left( {\alpha ,\beta } \right)} \left( x \right)$.
Usage
jacobi.p.weight(x,alpha,beta)
Arguments
x
the function argument which can be a vector
alpha
the first polynomial parameter
beta
the second polynomial parameter
Value
The value of the weight function
Details
The function takes on non-zero values in the interval $\left( -1,1 \right)$. The formula
used to compute the weight function is as follows.
$w\left( x \right) = \left( {1 - x} \right)^\alpha \;\left( {1 + x} \right)^\beta$
References
Abramowitz, M. and I. A. Stegun, 1968. Handbook of Mathematical Functions with
Formulas, Graphs, and Mathematical Tables, Dover Publications, Inc., New York.
Courant, R., and D. Hilbert, 1989. Methods of Mathematical Physics,
John Wiley, New York, NY.
Press, W. H., S. A. Teukolsky, W. T. Vetterling, and B. P. Flannery, 1992.
Numerical Recipes in C, Cambridge University Press, Cambridge, U.K.
Szego, G., 1939. Orthogonal Polynomials, 23, American Mathematical Society
Colloquium Publications, Providence, RI.