Learn R Programming

orthopolynom (version 1.0-2)

laguerre.polynomials: Create list of Laguerre polynomials

Description

This function returns a list with $n$+1 elements containing the order $k$ Laguerre polynomials, $L_n \left( x \right)$, for orders $k$ = 0, 1, ..., $n$.

Usage

laguerre.polynomials(n, normalized=FALSE)

Arguments

n
integer highest polynomial order
normalized
a boolean value which, if TRUE, returns a list of normalized orthogonal polynomials

Value

  • A list of $n$+1 polynomial objects
  • 1order 0 Laguerre polynomial
  • 2order 1 Laguerre polynomial
  • ...
  • n+1order $n$ Laguerre polynomial

Details

The function produces a data frame with the recurrence relation parameters for the orthogonal polynomials. It then uses the function orthogonal.polynomials to construct the list of polynomial objects from the recurrence relations.

References

Abramowitz and Stegun (1968)

See Also

laguerre.recurrences, orthogonal.polynomials, orthonormal.polynomials

Examples

Run this code
normalized.p.list <- laguerre.polynomials( 10, normalized=TRUE )
unnormalized.p.list <- laguerre.polynomials( 10, normalized=FALSE )

Run the code above in your browser using DataLab