Learn R Programming

orthopolynom (version 1.0-2)

monic.polynomial.recurrences: Create data frame of monic recurrences

Description

This function returns a data frame with parameters required to construct monic orthogonal polynomials based on the standard recurrence relation for the non-monic polynomials. The recurrence relation for monic orthogonal polynomials is as follows. $$q_{k + 1} \left( x \right) = \left( {x - a_k } \right)\;q_k \left( x \right) - b_k \;q_{k - 1} \left( x \right)$$ We require that $q_{-1} \left( x \right) = 0$ and $q_0 \left( x \right) = 1$. The recurrence for non-monic orthogonal polynomials is given by $$c_k \;p_{k + 1} \left( x \right) = \left( {d_k + e_k \;x} \right)\;p_k \left( x \right) - f_k \;p_{k - 1} \left( x \right)$$ We require that $p_{-1} \left( x \right) = 0$ and $p_0 \left( x \right) = 1$. The monic polynomial recurrence parameters, a and b, are related to the non-monic polynomial parameter vectors c, d, e and f in the following manner. $$a_k = - \frac{{d_k }}{{e_k }}$$ $$b_k = \frac{{c_{k - 1} \;f_k }}{{e_{k - 1} \;e_k }}$$ with $b_0 = 0$.

Usage

monic.polynomial.recurrences(recurrences)

Arguments

recurrences
the data frame of recurrence parameter vectors c, d, e and f

Value

  • A data frame with $n$+1 rows and two named columns, a and b.

References

Press, et al (1992)

See Also

orthogonal.polynomials,

Examples

Run this code
r <- chebyshev.t.recurrences( 10, normalized=TRUE )
m.r <- monic.polynomial.recurrences( r )

Run the code above in your browser using DataLab