Learn R Programming

orthopolynom (version 1.0-2)

polynomial.derivatives: Create list of polynomial derivatives

Description

This function returns a list with $n$+1 elements containing polynomial objects which are the derivatives of the order $k$ polynomials for orders $k$ = 0, ... , $n$.

Usage

polynomial.derivatives(polynomials)

Arguments

polynomials
list of polynomial objects

Value

  • List of polynomial objects
  • 1derivative of polynomials[[1]]
  • 2derivative of polynomials[[2]]
  • ...
  • n+1derivative of polynomials[[n+1]]

Details

The polynomial objects in the argument polynomials are as follows
  • 1
{order 0 polynomial} 2{order 1 polynomial} ... n+1{order n polynomial}

See Also

deriv.polynomial

Examples

Run this code
p.list <- chebyshev.t.polynomials( 10, normalized=TRUE )
p.deriv <- polynomial.derivatives( p.list )

Run the code above in your browser using DataLab