Learn R Programming

orthopolynom (version 1.0-3)

polynomial.functions: Coerce polynomials to functions

Description

This function returns a list with $n + 1$ elements containing the functions of the order $k$ polynomials for orders $k = 0,\;1,\; \ldots ,\;n$ and for the given argument $x$.

Usage

polynomial.functions(polynomials, ...)

Arguments

polynomials
a list of polynomial objects
...
further arguments to be passed to or from methods

Value

  • A list of $n + 1$ polynomial objects where each element is the function for the polynomial.
  • 1Function for the order 0 polynomial
  • 2Function for the order 1 polynomial
  • ...
  • n+1Function for the order $n$ polynomial

Details

The function uses the method as.function.polynomial to coerce each polynomial object to a function object.

Examples

Run this code
###
### generate a list of T Chebyshev polynomials of
### orders 0 to 10
###
p.list <- chebyshev.t.polynomials( 10, normalized=FALSE )
###
### create the list of functions for each polynomial
###
f.list <- polynomial.functions( p.list )

Run the code above in your browser using DataLab