Learn R Programming

orthopolynom (version 1.0-4)

polynomial.integrals: Create list of polynomial integrals

Description

This function returns a list with $n + 1$ elements containing polynomial objects which are the indefinite integrals of the order $k$ polynomials for orders $k = 0,\;1,\; \ldots ,\;n$.

Usage

polynomial.integrals(polynomials)

Arguments

polynomials
list of polynomial objects

Value

  • List of $n + 1$ polynomial objects
  • 1integral of polynomials[[1]]
  • 2integral of polynomials[[2]]
  • ...
  • n+1integral of polynomials[[n+1]]

Details

The polynomial objects in the argument polynomials are as follows
  • 1
{order 0 polynomial} 2{order 1 polynomial} ... n+1{order n polynomial}

Examples

Run this code
###
### generate a list of normalized T Chebyshev polynomials
### of orders 0 to 10
###
p.list <- chebyshev.t.polynomials( 10, normalized=TRUE )
###
### generate the corresponding list of polynomial integrals
###
p.int <- polynomial.integrals( p.list )

Run the code above in your browser using DataLab