Learn R Programming

orthopolynom (version 1.0-3)

polynomial.powers: Create a list of polynomial linear combinations

Description

This function returns a list with $n + 1$ elements containing the vector of linear combinations of the order $k$ polynomials for orders $k = 0,\;1,\; \ldots ,\;n$. Each element in the list is a vector.

Usage

polynomial.powers(polynomials)

Arguments

polynomials
A list of polynomials

Value

  • A list of $n + 1$ elements where each element is a vector of linear combinations.
  • 1Linear combination(s) of polynomials up to order 0
  • 2Linear combination(s) of polynomials up to order 1
  • ...
  • n+1Linear combination(s) of polynomials up to order $n$

Details

The $j$-th component in the list is a vector of linear combinations of the order $k$ polynomials for orders $k = 0,\;1,\; \ldots ,\;j - 1$ equal to the monomial x raised to the power $j - 1$.

Examples

Run this code
###
### generate Legendre polynomials of orders 0 to 10
###
polynomials <- legendre.polynomials( 10 )
###
### generate list of linear combinations of these polynomials
###
alphas <- polynomial.powers( polynomials )
print( alphas )

Run the code above in your browser using DataLab