Learn R Programming

orthopolynom (version 1.0-2)

polynomial.roots: Create a list of polynomial roots

Description

This function returns a list with $n$ elements containing the roots of the order $k$ monic orthogonal polynomials for orders $k$ = 1, ... , $n$ using a data frame with the monic polynomial recurrence parameter vectors $\bf{a}$ and $\bf{b}$

Usage

polynomial.roots(m.r)

Arguments

m.r
monic recurrence data frame with parameters a and b

Value

  • A list with n elements each of which is a vector of polynomial roots
  • 1roots of the order 1 monic polynomial
  • 2roots of the order 2 monic polynomial
  • ...
  • nroots of the order $n$ monic polynomial

Details

The parameter m.r is a data frame with $n$+1 rows and two names columns. The columns which are names a and b correspond to the above referenced vectors. Function jacobi.matrices is used to create a list of symmetric, tridiagonal Jacobi matrices from these named columns. The eigenvalues of the $k \times k$ Jacobi matrix are the roots or zeros of the order $k$ monic orthogonal polynomial.

References

Press, et. al. (1992)

See Also

monic.polynomial.recurrences jacobi.matrices, eigen

Examples

Run this code
r <- chebyshev.t.recurrences( 10, normalized=TRUE )
m.r <- monic.polynomial.recurrences( r )
p.roots <- polynomial.roots( m.r )

Run the code above in your browser using DataLab