Learn R Programming

orthopolynom (version 1.0-4)

polynomial.values: Create vector of polynomial values

Description

This function returns a list with $n + 1$ elements containing the values of the order $k$ polynomials for orders $k = 0,\;1,\; \ldots ,\;n$ and for the given argument $x$.

Usage

polynomial.values( polynomials, x )

Arguments

polynomials
list of polynomial objects
x
the argument which can be any numeric object

Value

  • A list of $n + 1$ polynomial objects where each element is the value of the polynomial.
  • 1Value(s) for the order 0 polynomial
  • 2Value(s) for the order 1 polynomial
  • ...
  • n+1Value(s) for the order $n$ polynomial

Examples

Run this code
###
### generate a list of T Chebyshev polynomials of
### orders 0 to 10
###
p.list <- chebyshev.t.polynomials( 10, normalized=FALSE )
x <- seq( -2, 2, .01 )
###
### compute the value of the polynomials for the given range of values in x
###
y <- polynomial.values( p.list, x )
print( y )

Run the code above in your browser using DataLab