schebyshev.t.inner.products: Inner products of shifted Chebyshev polynomials
Description
This function returns a vector with $n$+1 elements containing the inner product of an order $k$ shifted Chebyshev polynomial of the first kind, $T_k^* \left( x\right)$, with itself (i.e. the norm squared) for orders $k$ = 0, 1, ... , $n$.
Usage
schebyshev.t.inner.products(n)
Arguments
n
integer highest polynomial order
Value
A vector with $n$+1 elements
1inner product of order 0 orthogonal polynomial
2inner product of order 1 orthogonal polynomial
...
n+1inner product of order $n$+1 orthogonal polynomial
Details
~~ If necessary, more details than the description above ~~