schebyshev.t.weight: Weight function for the shifted Chebyshev polynomial
Description
This function returns the value of the weight function for the order $k$
shifted Chebyshev polynomial of the first kind, $T_k^* \left( x \right)$.
Usage
schebyshev.t.weight(x)
Arguments
x
the function argument which can be a vector
Value
The value of the weight function
Details
The function takes on non-zero values in the interval $\left( 0,1 \right)$. The formula
used to compute the weight function is as follows.
$w\left( x \right) = \frac{1}{{\sqrt {x - x^2 } }}$
References
Abramowitz, M. and I. A. Stegun, 1968. Handbook of Mathematical Functions with
Formulas, Graphs, and Mathematical Tables, Dover Publications, Inc., New York.
Courant, R., and D. Hilbert, 1989. Methods of Mathematical Physics,
John Wiley, New York, NY.
Press, W. H., S. A. Teukolsky, W. T. Vetterling, and B. P. Flannery, 1992.
Numerical Recipes in C, Cambridge University Press, Cambridge, U.K.
Szego, G., 1939. Orthogonal Polynomials, 23, American Mathematical Society
Colloquium Publications, Providence, RI.
###### compute the shifted T Chebyshev weight function for argument values### between 0 and 1x <- seq( 0, 1, .01 )
y <- schebyshev.t.weight( x )
plot( x, y )