Learn R Programming

orthopolynom (version 1.0-2)

spherical.inner.products: Inner products of spherical polynomials

Description

This function returns a vector with $n$+1 elements containing the inner product of an order $k$ spherical polynomial, $P_k \left( x \right)$, with itself (i.e. the norm squared) for orders $k$ = 0, 1, ... , $n$.

Usage

spherical.inner.products(n)

Arguments

n
integer highest polynomial order

Value

  • A vector with $n$+1 elements
  • 1inner product of order 0 orthogonal polynomial
  • 2inner product of order 1 orthogonal polynomial
  • ...
  • n+1inner product of order $n$+1 orthogonal polynomial

Details

~~ If necessary, more details than the description above ~~

References

Abramowitz and Stegun (1968)

Examples

Run this code
h <- spherical.inner.products( 10 )

Run the code above in your browser using DataLab