ultraspherical.weight: Weight function for the ultraspherical polynomial
Description
This function returns the value of the weight function for the order $k$ ultraspherical polynomial, $C_k^{\left( \alpha \right)} \left( x \right)$.
Usage
ultraspherical.weight(x,alpha)
Arguments
x
the function argument which can be a vector
alpha
polynomial parameter
Value
The value of the weight function
Details
The function takes on non-zero values in the interval $\left( -1,1 \right)$. The formula used
to compute the weight function is as follows.
$w\left( x \right) = \left( {1 - x^2 } \right)^{\alpha - 0.5}$
References
Abramowitz, M. and I. A. Stegun, 1968. Handbook of Mathematical Functions with
Formulas, Graphs, and Mathematical Tables, Dover Publications, Inc., New York.
Courant, R., and D. Hilbert, 1989. Methods of Mathematical Physics,
John Wiley, New York, NY.
Press, W. H., S. A. Teukolsky, W. T. Vetterling, and B. P. Flannery, 1992.
Numerical Recipes in C, Cambridge University Press, Cambridge, U.K.
Szego, G., 1939. Orthogonal Polynomials, 23, American Mathematical Society
Colloquium Publications, Providence, RI.
###### compute the ultraspherical weight function for arguments between -2 and 2### polynomial parameter is 1.0###x <- seq( -2, 2, .01 )
y <- ultraspherical.weight( x, 1 )
plot( x, y )