gegenbauer.polynomials: Create list of Gegenbauer polynomials
Description
This function returns a list with $n$+1 elements containing the order $k$ Gegenbauer polynomials, $C_k^{\left( \alpha \right)} \left( x \right)$, for orders $k$ = 0, 1, ..., $n$.
a boolean value which, if TRUE, returns a list of normalized orthogonal polynomials
Value
A list of $n$+1 polynomial objects
1order 0 Gegenbauer polynomial
2order 1 Gegenbauer polynomial
...
n+1order $n$ Chebyshev polynomial
Details
The function produces a data frame with the recurrence relation parameters for the orthogonal polynomials. It then uses the function orthogonal.polynomials to construct the list of polynomial objects from the recurrence relations.