gegenbauer.recurrences: Recurrence relations for Gegenbauer polynomials
Description
This function returns a data frame with $n$+1 rows and four named columns containing the coefficient vectors c, d, e and f of the recurrence relations for the order $k$ Gegenbauer polynomial, $C_k^{\left( \alpha \right)} \left( x \right)$, and for orders $k$ = 0, 1, ... , $n$.