ghermite.h.recurrences: Recurrence relations for generalized Hermite polynomials
Description
This function returns a data frame with $n$+1 rows and four named columns containing the coefficient vectors
c, d, e and f of the recurrence relations for the order $k$ generalized Hermite polynomial,
$H_k^{\left( \mu \right)} \left( x \right)$, and for orders $k$ = 0, 1, ... , $n$.
Usage
ghermite.h.recurrences(n, mu, normalized = FALSE)
Arguments
n
n integer highest polynomial order
mu
mu polynomial parameter
normalized
normalized boolean value which, if TRUE, returns recurrence relations for normalized polynomials
Value
A data frame with the recurrence relation parameters.