jacobi.g.recurrences: Recurrence relations for Jacobi polynomials
Description
This function returns a data frame with $n$+1 rows and four named columns containing the coefficient vectors c, d, e and f of the recurrence relations for the order $k$ Jacobi polynomial, $G_k \left( {p,q,x} \right)$, and for orders $k$ = 0, 1, ... , $n$.
Usage
jacobi.g.recurrences(n, p, q, normalized=FALSE)
Arguments
n
integer highest polynomial order
p
first polynomial parameter
q
second polynomial parameter
normalized
boolean value which, if TRUE, returns recurrence relations for normalized polynomials
Value
A data frame with the recurrence relation parameters.