jacobi.matrices: Create list of Jacobi matrices from monic recurrence parameters
Description
Return a list of $n$ real symmetric, tri-diagonal matrices which are
the principal minors of the $n \times n$ Jacobi matrix derived from
the monic recurrence parameters, $a$ and $b$, for orthogonal polynomials.
Usage
jacobi.matrices(r)
Arguments
r
a data frame containing the parameters $a$ and $b$
Value
A list of symmetric, tri-diagnonal matrices
1a $1 \times 1$ matrix
2a $2 \times 2$ matrix
...
nan $n \times n$ matrix
References
Press, W. H., S. A. Teukolsky, W. T. Vetterling, and B. P. Flannery, 1992.
Numerical Recipes in C, Cambridge University Press, Cambridge, U.K.