jacobi.matrices: Create list of Jacobi matrices from monic recurrence parameters
Description
Return a list of $n$ real symmetric, tri-diagonal matrices which are the principal minors of the $n \times n$ Jacobi matrix derived from the monic recurrence parameters, $a$ and $b$, for orthogonal polynomials.
Usage
jacobi.matrices(r)
Arguments
r
a data frame containing the parameters $a$ and $b$