jacobi.p.recurrences: Recurrence relations for Jacobi polynomials
Description
This function returns a data frame with $n$+1 rows and four named columns containing the coefficient vectors c, d, e and f of the recurrence relations for the order $k$ Jacobi polynomial, $P_k^{\left( {\alpha ,\beta } \right)} \left( x \right)$, and for orders $k$ = 0, 1, ... , $n$.
Usage
jacobi.p.recurrences(n, a, b, normalized=FALSE)
Arguments
n
integer highest polynomial order
a
first polynomial parameter
b
second polynomial parameter
normalized
boolean value which, if TRUE, returns recurrence relations for normalized polynomials
Value
A data frame with the recurrence relation parameters.