Create list of orthogonal polynomials from the following recurrence relations for $k$ = 0, 1,...$n$.
$$c_k p_{k+1}\left( x \right) = \left( d_k + e_k x \right) p_k \left( x \right) - f_k p_{k-1} \left( x \right)$$
We require that $p_{-1} \left( x \right) = 0$ and $p_0 \left( x \right) = 1$. The coefficients are the column vectors ${\bf{c}}$, ${\bf{d}}$, ${\bf{e}}$ and ${\bf{f}}$.
Usage
orthogonal.polynomials(recurrences)
Arguments
recurrences
a data frame containing the parameters of the orthogonal polynomial recurrence relations
Value
A list of polynomial objects
1Order 0 orthogonal polynomial
2Order 1 orthogonal polynomial
...
n+1Order $n$ orthogonal polynomial
Details
The argument is a data frame with $n$+1 rows and four named columns. The column names are c, d, e and f. These columns correspond to the column vectors described above.
References
Abramowitz and Stegun (1968) and Press, et. al. (1992)