Learn R Programming

orthopolynom (version 1.0-2)

polynomial.coefficients: Create list of polynomial coefficient vectors

Description

This function returns a list with $n$+1 elements containing the vector of coefficients of the order $k$ polynomials for orders $k$ = 0, 1,..., $n$. Each element in the list is a vector.

Usage

polynomial.coefficients(polynomials)

Arguments

polynomials
list of polynomial objects

Value

  • A list of $n$+1 polynomial objects where each element is a vector of coefficients.
  • 1Coefficient(s) of the order 0 polynomial
  • 2Coefficient(s) of the order 1 polynomial
  • ...
  • n+1Coefficient(s) of the order $n$ polynomial

See Also

predict.polynomial

Examples

Run this code
p.list <- chebyshev.t.polynomials( 10, normalized=TRUE )
p.coef <- polynomial.coefficients( p.list )

Run the code above in your browser using DataLab