polynomial.integrals: Create list of polynomial integrals
Description
This function returns a list with $n$+1 elements containing polynomial objects which are the indefinite integrals of the order $k$ polynomials for orders $k$ = 0, ... , $n$.
Usage
polynomial.integrals(polynomials)
Arguments
polynomials
list of polynomial objects
Value
List of polynomial objects
1integral of polynomials[[1]]
2integral of polynomials[[2]]
...
n+1integral of polynomials[[n+1]]
Details
The polynomial objects in the argument polynomials are as follows
1
{order 0 polynomial}
2{order 1 polynomial}
...
n+1{order n polynomial}