schebyshev.t.polynomials: Create list of shifted Chebyshev polynomials
Description
This function returns a list with $n$+1 elements containing the order $k$ shifted Chebyshev polynomials of the first kind, $T_k^* \left( x\right)$, for orders $k$ = 0, 1, ..., $n$.
Usage
schebyshev.t.polynomials(n, normalized)
Arguments
n
integer highest polynomial order
normalized
a boolean value which, if TRUE, returns a list of normalized orthogonal polynomials
Value
A list of $n$+1 polynomial objects
1order 0 shifted Chebyshev polynomial
2order 1 shifted Chebyshev polynomial
...
n+1order $n$ shifted Chebyshev polynomial
Details
The function produces a data frame with the recurrence relation parameters for the orthogonal polynomials. It then uses the function orthogonal.polynomials to construct the list of polynomial objects from the recurrence relations.