spherical.recurrences: Recurrence relations for spherical polynomials
Description
This function returns a data frame with $n$+1 rows and four named columns containing the coefficient vectors c, d, e and f of the recurrence relations for the order $k$ spherical polynomial, $P_k \left( x \right)$, and for orders $k$ = 0, 1, ... , $n$.
Usage
spherical.recurrences(n, normalized=FALSE)
Arguments
n
integer highest polynomial order
normalized
boolean value which, if TRUE, returns recurrence relations for normalized polynomials
Value
A data frame with the recurrence relation parameters.